library(ape)

querySequenceNum <- NULL; 
rootSpeciesNums <- NULL;

infileName <- "infile.txt"
outfileName <- "treePlot.png"

infile <- read.table(infileName, na.strings = FALSE)

linePickUpFromModFasta <- function(lines, keyWord)
{
  container <- c()
  frag <- 0
  lineStock <- c()
  for(line in lines) {

  ### Collect lines 
  if (regexpr('^>', line) < 0) {
    if(frag == 1) {
      lineStock <- c(lineStock, line)
    }
  }
  
  if (regexpr('^>', line) > 0) {
     if(frag == 1)
     {
       container <- c(container, lineStock)
       lineStock <- c()
       break
     }

     keyWord1 <- paste('>', keyWord, sep='')
     if (regexpr(keyWord1, line) > 0)
     {
       container <- c(container, line)
       frag <- 1
     }
   }
  }
  container <- c(container, lineStock)    
  container <- container[-1]
  #print('container')
  #print(container)
#  cat('\n')
  return(container)
}


## A function to check the presence or absence of subject
presenceCheckInModFasta <- function (linesA, keyWordA)
{
  if(any(i <- grep(keyWordA,infile$V1)))
  {
    containerA <- linePickUpFromModFasta(linesA,keyWordA)
  } else {
    # print (paste('  ',keyWordA,' does not exist.', sep=''))
    containerA  <- NULL
  }
  return(containerA)
}

name_querySequence <- presenceCheckInModFasta(infile$V1, "QuerySequence") 
names_rootSpecies <- presenceCheckInModFasta(infile$V1, "Rooting") 
tr <- presenceCheckInModFasta(infile$V1, "NewickTree") 
tr <- read.tree(text = tr)
tr <- ladderize(tr, FALSE) # ladderize(tr,FALSE)


########## Main program
## Pick up the tip numbers
for(i in 1:length(tr$tip.label)){
  ## query
  if(regexpr(name_querySequence, tr$tip.label[i]) > 0){
    querySequenceNum <- i
  }

  ## root
  for (name_rootSpecies in names_rootSpecies){
    if(regexpr(name_rootSpecies, tr$tip.label[i]) > 0){
      rootSpeciesNums <- c(rootSpeciesNums, i)
    }
  }

}


## Bold character
fontNum <- rep(1, length(tr$tip.label))
fontNum[querySequenceNum] <- 4

## Branch width
if(is.null(querySequenceNum)){
  edgeWidth <- rep(1.5, dim(tr$edge)[1])
} else {
  num_leaf <- c(querySequenceNum)
  print("num_leaf1")
  print(num_leaf)
  num_leaf <- c(num_leaf, rootSpeciesNums)
  print("num_leaf2")
  print(num_leaf)

  whHF <- which.edge(tr, num_leaf)
  print("whHF")
  print(whHF)
  edgeWidth       <- rep(1.5, dim(tr$edge)[1])
  edgeWidth[whHF] <- 4
}
print("edgeWidth")
print(edgeWidth)


## Printout
png(outfileName) 
plot(tr, no.margin=TRUE, underscore = TRUE, use.edge.length=FALSE, label.offset = 1, cex = 0.9, edge.width = edgeWidth)
nodelabels(tr$node.label, adj = c(1.2,-0.5), cex=1, frame = "n")
dev.off() 
